#!/bin/sh
echo 'name: conduit
version: 1.0.2
id: conduit-1.0.2-84e4a01a85b985d5c5c6216348861654

license: BSD3
copyright:
maintainer: michael@snoyman.com
stability:
homepage: http://github.com/snoyberg/conduit
package-url:
synopsis: Streaming data processing library.
description: @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://haskell.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
             .
             Release history:
             .
             [1.0] Simplified the user-facing interface back to the Source, Sink, and Conduit types, with Producer and Consumer for generic code. Error messages have been simplified, and optional leftovers and upstream terminators have been removed from the external API. Some long-deprecated functions were finally removed.
             .
             [0.5] The internals of the package are now separated to the .Internal module, leaving only the higher-level interface in the advertised API. Internally, switched to a @Leftover@ constructor and slightly tweaked the finalization semantics.
             .
             [0.4] Inspired by the design of the pipes package: we now have a single unified type underlying @Source@, @Sink@, and @Conduit@. This type is named @Pipe@. There are type synonyms provided for the other three types. Additionally, @BufferedSource@ is no longer provided. Instead, the connect-and-resume operator, @$$+@, can be used for the same purpose.
             .
             [0.3] ResourceT has been greatly simplified, specialized for IO, and moved into a separate package. Instead of hard-coding ResourceT into the conduit datatypes, they can now live around any monad. The Conduit datatype has been enhanced to better allow generation of streaming output. The SourceResult, SinkResult, and ConduitResult datatypes have been removed entirely.
             .
             [0.2] Instead of storing state in mutable variables, we now use CPS. A @Source@ returns the next @Source@, and likewise for @Sink@s and @Conduit@s. Not only does this take better advantage of GHC\'\''s optimizations (about a 20% speedup), but it allows some operations to have a reduction in algorithmic complexity from exponential to linear. This also allowed us to remove the @Prepared@ set of types. Also, the @State@ functions (e.g., @sinkState@) use better constructors for return types, avoiding the need for a dummy state on completion.
             .
             [0.1] @BufferedSource@ is now an abstract type, and has a much more efficient internal representation. The result was a 41% speedup on microbenchmarks (note: do not expect speedups anywhere near that in real usage). In general, we are moving towards @BufferedSource@ being a specific tool used internally as needed, but using @Source@ for all external APIs.
             .
             [0.0] Initial release.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules: Data.Conduit Data.Conduit.Binary Data.Conduit.Text
                 Data.Conduit.List Data.Conduit.Lazy Data.Conduit.Internal
                 Data.Conduit.Util
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/conduit-1.0.2
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/conduit-1.0.2
              /usr/local/lib
hs-libraries: HSconduit-1.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         lifted-base-0.2.0.2-65026d342578be3594c04d8e1209e3d8
         monad-control-0.3.1.4-83560fedcd54bda582bc1867a61c5f8a
         resourcet-0.4.5-48a9c2e771698aeb3c5b0da579a5f0c8
         text-0.11.2.3-116e588a2afe9f305204001245768a0d
         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
         transformers-base-0.4.1-8ce92ed550a5d340c6fea5db639117cb
         void-0.5.11-a88f44f0e8fc1d21f0c1a23f0996294f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/conduit-1.0.2/html/conduit.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/conduit-1.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
